"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var Promise = require("bluebird");
var retry = require("bluebird-retry");
var chokidar_1 = require("chokidar");
var path = require("path");
var api_1 = require("./api");
var local_fs_crud_only_1 = require("./local-fs-crud-only");
var LocalFileSystem = (function (_super) {
    __extends(LocalFileSystem, _super);
    function LocalFileSystem(baseUrl, ignore, retrySettings) {
        if (retrySettings === void 0) { retrySettings = {
            interval: 100,
            max_tries: 3
        }; }
        var _this = _super.call(this, baseUrl, ignore) || this;
        _this.baseUrl = baseUrl;
        _this.retrySettings = retrySettings;
        return _this;
    }
    LocalFileSystem.prototype.init = function () {
        var _this = this;
        this.watcher = chokidar_1.watch([this.baseUrl], {
            //  usePolling:true,
            //  interval:100,
            ignored: function (path) { return _this.isIgnored(path); },
            //    atomic: false, //todo 50?
            cwd: this.baseUrl
        });
        this.watcher.on('error', function (err) { return console.log('Error in LocalFileSystem watch', err); });
        return new Promise(function (resolve) {
            _this.watcher.once('ready', function () {
                _this.watcher.on('addDir', function (relPath, stats) {
                    if (relPath) {
                        _this.events.emit('directoryCreated', {
                            type: 'directoryCreated',
                            fullPath: relPath.split(path.sep).join(api_1.pathSeparator)
                        });
                    }
                });
                _this.watcher.on('add', function (relPath) {
                    retry(function () { return _this.loadTextFile(relPath)
                        .then(function (content) { return _this.events.emit('fileCreated', {
                        type: 'fileCreated',
                        fullPath: relPath.split(path.sep).join(api_1.pathSeparator),
                        newContent: content
                    }); }); }, _this.retrySettings).catch(function () { return _this.events.emit('unexpectedError', { type: 'unexpectedError' }); });
                });
                _this.watcher.on('change', function (relPath) {
                    retry(function () { return _this.loadTextFile(relPath)
                        .then(function (content) { return _this.events.emit('fileChanged', {
                        type: 'fileChanged',
                        fullPath: relPath.split(path.sep).join(api_1.pathSeparator),
                        newContent: content
                    }); }); }, _this.retrySettings).catch(function () { return _this.events.emit('unexpectedError', { type: 'unexpectedError' }); });
                });
                _this.watcher.on('unlinkDir', function (relPath) {
                    return _this.events.emit('directoryDeleted', {
                        type: 'directoryDeleted',
                        fullPath: relPath.split(path.sep).join(api_1.pathSeparator)
                    });
                });
                _this.watcher.on('unlink', function (relPath) {
                    return _this.events.emit('fileDeleted', {
                        type: 'fileDeleted',
                        fullPath: relPath.split(path.sep).join(api_1.pathSeparator)
                    });
                });
                resolve(_this);
            });
        });
    };
    LocalFileSystem.prototype.dispose = function () {
        this.watcher.close();
    };
    return LocalFileSystem;
}(local_fs_crud_only_1.LocalFileSystemCrudOnly));
exports.LocalFileSystem = LocalFileSystem;
//# sourceMappingURL=local-fs.js.map