"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var Promise = require("bluebird");
var retry = require("bluebird-retry");
var EventsMatcher = (function () {
    function EventsMatcher(options) {
        this.options = options;
        this.events = [];
    }
    EventsMatcher.prototype.track = function (emitter) {
        var _this = this;
        var eventNames = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            eventNames[_i - 1] = arguments[_i];
        }
        eventNames.forEach(function (eventName) { return emitter.on(eventName, function (event) {
            chai_1.expect(event.type, "type of event dispatched as " + eventName).to.eql(eventName);
            _this.events.push(event);
        }); });
    };
    EventsMatcher.prototype.expectEvents = function (events) {
        if (events.length) {
            return retry(this.checkEvents.bind(this, events), this.options)
                .then(function () { return undefined; })
                .catch(function (e) {
                throw e.failure;
            });
        }
        else {
            chai_1.expect(this.events).to.eql([]);
            return Promise.resolve();
        }
    };
    EventsMatcher.prototype.expect = function (events) {
        var _this = this;
        return this.expectEvents(events)
            .delay(this.options.noExtraEventsGrace)
            .then(function () {
            chai_1.expect(_this.events, 'no further events after matching').to.eql([]);
        });
    };
    EventsMatcher.prototype.checkEvents = function (events) {
        try {
            chai_1.expect(this.events).to.containSubset(events);
            this.events = [];
            return Promise.resolve();
        }
        catch (e) {
            return Promise.reject(e);
        }
    };
    return EventsMatcher;
}());
exports.EventsMatcher = EventsMatcher;
//# sourceMappingURL=events-matcher.js.map